%Example program for the DataqSDK.NET control with a DI-1120 in MATLAB. 
%Prerequisites: WinDaq software installed, DI-1120 hardware installed,
%DATAQ SDK installation must be newer than 12/8/17.
%Please submit any questions about this program online at: http://www.dataq.com/ticket/

%Make the .NET DATAQ SDK assembly visible to MATLAB
%The file path for the .dll's will vary depending on your OS and installation version.  
%The dll's will only need to be added the first time you run the program
NET.addAssembly('C:\Windows\Microsoft.NET\assembly\GAC_MSIL\Dataq\v4.0_2.1.0.0__9767f47f9c295223\Dataq.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Devices.Main\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Devices.Main.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Platforms\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Platforms.dll');
NET.addAssembly('C:\WINDOWS\Microsoft.NET\assembly\GAC_MSIL\Dataq.Protocols\v4.0_2.1.0.0__9767f47f9c295223\Dataq.Protocols.dll');

%Locate your DI-1120 by the Serial Number
%CHANGE SERIAL NUMBER TO THE SERIAL NUMBER ON THE BOTTOM OF YOUR DEVICE
DIHardware = Dataq.Misc.Discovery.BySerialAsync('5976F9B3');

%Connect to your DI-1120
myDI1120 = DIHardware.Result;
try
    myDI1120.ConnectAsync.Result;
catch ME
    disp(ME.message);
end

%Display the properties and methods of the Dataq.Devices.DI1120.Device
%class
properties(myDI1120)
methods(myDI1120)

%Display device information
disp('Manufacturer: ')
disp(myDI1120.Manufacturer)
disp('Model: ')
disp(myDI1120.Model)
disp('Serial: ')
disp(myDI1120.Serial)

%Demonstrate how to set the LED color, LED will flash blue once acquisition starts
%Red - 
myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Red)
%Black - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Black)
%Blue - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Blue)
%Green - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Green)
%Cyan - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Cyan)
%Magenta - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Magenta)
%Yellow - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.Yellow)
%White - myDI1120.Protocol.SetLedColorAsync(Dataq.Protocols.Enums.LedColor1.White)

%Initialize the device
myDI1120.Channels.Clear()

%Get supported channel types for the DI-1120
SupportedChannelTypes = myDI1120.SupportedChannels.GetEnumerator();
SupportedChannelTypes.MoveNext();
AnalogVoltageIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
DigitalOut = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
FrequencyIn = SupportedChannelTypes.Current.Key();
SupportedChannelTypes.MoveNext();
CounterIn = SupportedChannelTypes.Current.Key();

%Configure the Analog Channels
%Analog Channel 1
AnalogChan = myDI1120.ChannelFactory(AnalogVoltageIn,1);
%Acquisition Modes:
%Dataq.Devices.DI1120.CascadedIntegratorCombFilter
%Dataq.Devices.DI1120.MaximumSample
%Dataq.Devices.DI1120.MinimumSample
%Dataq.Devices.DI1120.LastSample
AnalogChan.AcquisitionMode = Dataq.Devices.DI1120.CascadedIntegratorCombFilter;
AnalogChan.HardwareRange.Minimum = -2;
AnalogChan.HardwareRange.Maximum = 2;
AnalogChan.AcquisitionMode.Samples = 64; %Decimation factor

%Analog Channel 2
AnalogChan = myDI1120.ChannelFactory(AnalogVoltageIn,2);
AnalogChan.AcquisitionMode = Dataq.Devices.DI1120.MaximumSample;
AnalogChan.HardwareRange.Minimum = -5;
AnalogChan.HardwareRange.Maximum = 5;
AnalogChan.AcquisitionMode.Samples = 64; %Decimation factor

%Analog Channel 3
AnalogChan = myDI1120.ChannelFactory(AnalogVoltageIn,3);
AnalogChan.AcquisitionMode = Dataq.Devices.DI1120.MinimumSample;
AnalogChan.HardwareRange.Minimum = -10;
AnalogChan.HardwareRange.Maximum = 10;
AnalogChan.AcquisitionMode.Samples = 64; %Decimation factor

%Analog Channel 4
AnalogChan = myDI1120.ChannelFactory(AnalogVoltageIn,4);
AnalogChan.AcquisitionMode = Dataq.Devices.DI1120.LastSample;
AnalogChan.HardwareRange.Minimum = -20;
AnalogChan.HardwareRange.Maximum = 20;
AnalogChan.AcquisitionMode.Samples = 64; %Decimation factor

%Display the sample rate per channel
FirstChannel = myDI1120.Channels.Item(0);
disp('Sample Rate per Channel: ')
disp(FirstChannel.GetSampleRate(myDI1120))

%Configure the device as defined
try
    myDI1120.InitializeAsync.Result; 
catch ME
    disp(ME.message);
end

%Start scanning
try
    myDI1120.AcquisitionStartAsync.Result;
catch ME
    disp(ME.message);
end

%Define the data array
DI_TempDataArray = {};

%Set an amount of time you want to collect data until the loop exits
DIRuntime = 10; %Time in seconds to acquire data
timerID = tic;  %Start a clock and return the timer ID

%Read data and display in Command Window
while myDI1120.IsAcquiring() && (toc(timerID) < DIRuntime);
    try
        %Refresh the buffer DataIn with new data
        myDI1120.ReadDataAsync.Result;
    catch ME
        disp(ME.message);
        break
    end

%Initialize temporary array to hold new data
DI_TempDataArray = [];

%Convert .NET array data to a double array with a 
%column for each enabled channel.
        for ColumnChan = 1:myDI1120.Channels.Count
            ch = myDI1120.Channels.Item(ColumnChan-1);
            DI_NewData = ch.DataIn.ToArray;
            DI_NewData = reshape(DI_NewData.double,[],1);
            if ColumnChan == 1 
                DI_TempDataArray = DI_NewData;
            else
                DI_TempDataArray(:,ColumnChan) = DI_NewData;
            end
            %Clear data from the buffer
            ch.DataIn.Clear;
        end  
        %Display the data in the command window
        disp(DI_TempDataArray)
end

%Stop scanning
myDI1120.AcquisitionStopAsync.Result;

%It is important to disconnect from the device.  If you have connected
%successfully to the device, but do not disconnect you may need to unplug
%your hardware from the USB cable before you can connect again.
myDI1120.Dispose;
DIHardware.Dispose;



 







